@@ -1,10 +1,10 @@
 #
-# $Id: Simple.pm,v 6683a807d2d6 2016/10/05 16:54:08 gomor $
+# $Id: Simple.pm,v f95f896d91d6 2017/05/07 12:57:38 gomor $
 #
 package Net::Frame::Simple;
 use warnings; use strict;
 
-our $VERSION = '1.07';
+our $VERSION = '1.08';
 
 use Class::Gomor::Array;
 use Exporter;
@@ -148,8 +148,11 @@ sub unpack {
 sub computeLengths {
    my $self = shift;
    my $layers = $self->[$__layers];
+   # currLayers is used to keep track of already processed layers.
+   my $currLayers;
    for my $l (reverse @$layers) {
-      $l->computeLengths($layers);
+      unshift @$currLayers, $l;
+      $l->computeLengths($currLayers);
    }
    return 1;
 }
@@ -549,7 +552,7 @@ Patrice E<lt>GomoRE<gt> Auffret
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2006-2016, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2006-2017, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of the Artistic license.
 See LICENSE.Artistic file in the source distribution archive.
